@@ -24,7 +24,9 @@ class DataSetsManager(ManagerMix):
 
         return data_sets
 
-    def data_set_by_code(self, site, element, aggregation, time_step, level):
+    def data_set_by_code(self, site, element, aggregation, time_step, level = None, elementMarkOverride = None):
+        if elementMarkOverride is not None:
+            element = elementMarkOverride
         code = element + "_" + aggregation + "_" + time_step
         if level is not None:
             code += "_" + level
